==> haskell-modern-uri-0.3.6.1-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-modern-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 modern-uri
version:              0.3.6.1
visibility:           public
id:                   modern-uri-0.3.6.1-JseycP2vtXr6yPC821LmF7
key:                  modern-uri-0.3.6.1-JseycP2vtXr6yPC821LmF7
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/modern-uri
synopsis:             Modern library for working with URIs
description:          Modern library for working with URIs.
category:             Text
abi:                  24807503581f42273c2c354056cfebf5
exposed:              True
exposed-modules:      Text.URI Text.URI.Lens Text.URI.QQ
hidden-modules:
    Text.URI.Parser.ByteString Text.URI.Parser.Text
    Text.URI.Parser.Text.Utils Text.URI.Render Text.URI.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/modern-uri-0.3.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/modern-uri-0.3.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/modern-uri-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-modern-uri
hs-libraries:         HSmodern-uri-0.3.6.1-JseycP2vtXr6yPC821LmF7
depends:
    QuickCheck-2.14.3-76HC5XzyauqDQFZ8BHcZeC base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    exceptions-0.10.5 hashable-1.4.4.0-1zcla4qwUGf6ADT5z5m7Nb
    megaparsec-9.6.1-Bx9HL7OUnKeEbRFabqUOjM mtl-2.2.2
    profunctors-5.6.3-L21qmF9iXw2FcRafgVQ9Hj
    reflection-2.1.9-KY42PT1YCOaFZDyHgCtGDU
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-modern-uri/html/modern-uri.haddock
haddock-html:         /usr/share/doc/haskell-modern-uri/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-modern-uri-0.3.6.1-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-modern-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 modern-uri
version:              0.3.6.1
visibility:           public
id:                   modern-uri-0.3.6.1-5SgmYGou2oIKNBGkjHRWWp
key:                  modern-uri-0.3.6.1-5SgmYGou2oIKNBGkjHRWWp
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/modern-uri
synopsis:             Modern library for working with URIs
description:          Modern library for working with URIs.
category:             Text
abi:                  6602c9f2fb54364709064188f4a09f5a
exposed:              True
exposed-modules:      Text.URI Text.URI.Lens Text.URI.QQ
hidden-modules:
    Text.URI.Parser.ByteString Text.URI.Parser.Text
    Text.URI.Parser.Text.Utils Text.URI.Render Text.URI.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/modern-uri-0.3.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/modern-uri-0.3.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/modern-uri-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-modern-uri
hs-libraries:         HSmodern-uri-0.3.6.1-5SgmYGou2oIKNBGkjHRWWp
depends:
    QuickCheck-2.14.3-6LKdi6bmSSC7fWzYy22Dkb base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    exceptions-0.10.5 hashable-1.4.4.0-9uPnQxUdwOnCZlD9EiHqMs
    megaparsec-9.6.1-AoOr20KJpsLF6iC5XVolQ8 mtl-2.2.2
    profunctors-5.6.3-Awvi78GiKWR1SSMXJ32bHl
    reflection-2.1.9-7o7Qx5LSVi7FQQfi2pCYIs
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-modern-uri/html/modern-uri.haddock
haddock-html:         /usr/share/doc/haskell-modern-uri/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
